#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['secretm']

package_data = \
{'': ['*']}

setup(name='secretm',
      version='0.0.1',
      description='A tiny secret manager written in python',
      author='Bailey Wickham',
      author_email='baileywickham@gmail.com',
      url='https://github.com/baileywickham/secrets',
      packages=packages,
      package_data=package_data,
     )
